<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BlockList</name>
    <message>
        <location filename="../BlockList.js" line="+453"/>
        <location line="+41"/>
        <location line="+39"/>
        <source>Block List</source>
        <translation>ブロックリスト</translation>
    </message>
    <message>
        <location line="-80"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Hide internal blocks</source>
        <translation>内側のブロックを非表示</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Enable alternating row colors</source>
        <translation>行の交互色を使用する</translation>
    </message>
</context>
</TS>
